Home page

Not knowing what to write at the home page yet. May be filled later.

If this is your first time visiting this site, here is a list of recommended readings:

Anyway, I can be contacted via the email address angeci (at) ltgc.cc. Sadly mails can’t be sent via this domain at the moment, so replies would be sent from another email address.

Translations can be submitted through email, or by issuing a PR on this GitHub repo.

There is no comment section at the beginning stage of the blog. (Cuz I’m too lazy to find a place to host the comment system; Would there be one after some time? Who knows.) Comments can be submitted through means like email or private messages, and the comments would be posted at the “Featured Comments” section at the end of each post.

大唐坤輿萬國全圖

Last updated on Monday, October 5, 2026

This page is still work in progress, stay focus for continuous upcoming updates on this page!

國家

ISO 3166-1 alpha-2英語原文社群自造稱呼現代漢語稱呼
ALAlbaniaShqipëria室執、室脂發梨耶
伊律離1
阿爾巴尼亞
AMArmeniaՀայաստան咍國、呵耶亞美尼亞
ARArgentinaArgentina遏軒滇、遏軒地那阿根廷
ATAustriaÖsterreich畏瀦賴
優悉瀦賴
隈隄黎
奧地利
AUAustraliaAustralia鏖悉吒離
鏖悉株梨與
澹部(意譯?)2
澳洲
澳大利亞
AZAzerbaijanAzərbaycan阿截旆禪
阿截旆常
阿塞拜疆
亞塞拜然
BABosnia and HerzegovinaBosna i Hercegovina蒲娑那與褉績劬毗那波斯尼亞和黑塞哥維那
波士尼亞與赫塞哥維納
BEBelgiumBelgië
Belgique
襒伽、襒蓋
襒利
比利時
BGBulgariaБългария勃揭
勃伽梨耶
保加利亞
BRBrazilBrasil拔囚、拔疾
佛羅疾
枋林(意譯)
巴西
BYBelarusБеларусь脾羅樓司白俄羅斯
白羅斯
CACanadaCanada迦那陀加拿大
CHSwitzerland
Suisse
Schweiz戌茲
榱司
榱滋
瑞士
CLChileChile鴟黎智利
CZCzechiaČesko戠國
萴國
制拘
捷克
DEGermanyDeutschland隤䲭
隤鑕
隤嗤
德國
德意志
DKDenmarkDanmark檀國
檀幕
丹麥
ECEcuadorEcuador益戈突
益粵堗
赤道(意譯)
厄瓜多爾
厄瓜多
EEEstoniaEesti翳悉氐
殹脂
愛沙尼亞
ESSpainEspaña司波尼
司般若
(東)佛郎機3
西班牙
FIFinlandSuomi須迷芬蘭
FRFranceFrance弗楞
法蘭西
方司
法國
法蘭西
GEGeorgiaსაქართველო渴襒
渴鍮梨
格魯吉亞
喬治亞
GRGreeceΕλλάδα希臘希臘
HRCroatiaHrvatska迄伐
迄婆稷
克羅地亞
克羅埃西亞
HUHungaryMagyarország馬揭
匈牙利4
匈牙利
IDIndonesiaIndonesia三佛齊、室利佛逝5印度尼西亞
印尼
IEIrelandÉire翳琉
鷖漦
愛爾蘭
ILIsraelיִשְׂרָאֵל肄羅噎以色列
INIndiaIndia天竺
身毒
印度
IRIranایران波斯4伊朗
ITItalyItalia伊多梨
有犢(來源待考)
意大利
義大利
JPJapan日本日本日本
KGKyrgyzstanКыргызстан骨㤥辭
厥㤥辭
吉爾吉斯斯坦
KZKazakhstanҚазақстан珂昨哈薩克斯坦
LALaosລາວ瀾滄6老撾
寮國
LTLithuaniaLietuva離兜婆
梨與兜婆
立陶宛
LULuxembourgLëtzebuerg
Luxembourg
閭匝佩盧森堡
LVLatviaLatvija剌毗耶拉脫維亞
MKNorth MacedoniaСеверна Македонија北摩企豚北馬其頓
MNMongoliaМонгол Улс蒙古
蒙兀
蒙古國
MTMaltaMalta末多馬爾他
MXMexicoMéxico迷尸拘
覓私拘
墨西哥
MYMalaysiaMalaysia馬來國馬來西亞
NGNigeriaNigeria柰視璃尼日利亞
奈及利亞
NLNetherlandsNederland尼突蘭
泥除蘭
尼德蘭
荷蘭
NONorwayNorge拏歷挪威
NZNew ZealandNew Zealand
Aotearoa
新西蘭
阿烏帝阿盧阿
新西蘭
紐西蘭
PHPhilippinesPhilippines非立賓
呂宋
菲律賓
PLPolandPolska勃國
哱息迦
孛烈兒(後起)
波蘭
PTPortugalPortugal鉢兜揭
埠吐噶
(西)佛郎機3
葡萄牙
RORomaniaRomânia盧門如羅馬尼亞
RSSerbiaСрбија悉立
悉釐毗耶
塞爾維亞
RURussiaРоссия樓司
羅剎
羅斯
俄羅斯
SESwedenSverige綏國、宣國7
眭璃
遂歷
瑞典
SISloveniaSlovenija悉盧駢如斯洛文尼亞
斯洛維尼亞
SKSlovakiaSlovensko悉盧駢息拘斯洛伐克
SOSomaliaSoomaaliya酥摩梨索馬里索
馬利亞
THThailandประเทศไทย暹羅8泰國
TRTurkeyTürkiye突厥土耳其
UAUkraineУкраїна屋冷
屋家寅
屋扢賴寅
屋羅夷那
渥蓮
烏克蘭
USUnited States of AmericaUnited States of America阿彌梨迦
阿篾力迦
美國
美利堅合眾國
UYUruguayUruguay甌樓回烏拉圭
UZUzbekistanOʻzbekiston迂習甓烏茲別克斯坦
VEVenezuelaVenezuela吠泥雪羅
吠泥朱羅9
駢迡雪羅
委內瑞拉
ZASouth AfricaSouth Africa南廅梨迦南非
南亞非利加

屬地或有限承認國家

ISO 3166-1 alpha-2英語原文社群自造稱呼現代漢語稱呼
FOFaroe IslandsFøroyar發抴諸島法羅群島
TWTaiwan臺灣琉求10臺灣
EnglandEngland英吉利英格籣
AsturiasAsturies阿悉兜璃阿斯圖里亞斯
阿斯土利亞
BashkortostanБашҡортостан旆骨巴什科爾托斯坦
BavariaBayern符袁巴伐利亞
BrittanyBreizh小不列顛布列塔尼
BrabantBraobant佛羅磐
卑蘭
布拉班特
布拉邦
CataloniaCatalunya迦多樓如
据多樓如
加泰羅尼亞
加泰隆尼亞
ChuvashiaЧӑваш諸越師
諸衞師
櫧旆
楚瓦什
WalesCymru劔祿11
劍梨
威爾斯
威爾士
AndalusiaAndaluçía安陀樓些
安陀樓私耶
安達盧西亞
安達魯西亞
FranconiaFranggn弗楞斤
兵芹
法蘭克尼亞
弗蘭肯
東法蘭克
FriuliFriûl弗梨鬱
悲鬱
佛里烏利
弗留利
FrieslandFryslân弗利司
悲息
菲士蘭
弗里士蘭
GaliciaGalicia伽梨私耶加利西亞
Galicia
Halychyna
Галичина荷梨脂那加利西亞
哈利奇那
HawaiiHawaiʻi呵倄伊夏威夷
CornwallKernow羯猱康沃爾
康瓦爾
LimburgLimburg林佩林堡
LombardyLombardia嵐跋倫巴第
倫巴底
PueblaNdanìngà沂禾普埃布拉
CantabriaCantabria犍多鉢離
鞬多岯與
坎塔布里亞
RutheniaПудкарпатя外揭鉢12
外羯波遮12
盧森尼亞
SakhaСаха爵佉13
娑呵
薩哈
SamiSápmi靸寐薩米
SaxonySaggsn塞蘇14
夕辛
薩克森
SilesiaŚlōnsk室菕息西利西亞
TatarstanТатарстан韃靼韃靼
ValenciaValencià婆憐些
婆憐私耶
瓦倫西亞
VenetoVèneto吠泥都
駢涅都
威尼托
אַשכּנזיש ייִדן頞式䞿柰
藹据那祠
阿什肯納茲
亞實基拿

其他

  • 有人謂中美洲曰「扶桑」,實與「東夷」同義,凡處中原之東皆屬之。且容易令今人聯想到日本。

  1. 古稱 Ἰλλυρία 也許能用? ↩︎

  2. 源自佛教概念「南贍部洲」。 ↩︎

  3. 源自他稱。明史謂「佛郎機」一詞未辨明現今之「西班牙」與「葡萄牙」,使用時需注意。 ↩︎ ↩︎

  4. 源自他稱。 ↩︎ ↩︎

  5. 來自古代名稱 Śrīvijaya。兩個漢字寫法皆見於中國古籍。 ↩︎

  6. 來自古代名稱 ລ້ານຊ້າງ。 ↩︎

  7. 古諾爾斯語 sví- /swi-/ 或 sven- /swen-/。 ↩︎

  8. 源自舊稱 สยาม。 ↩︎

  9. 新拉丁語 Ventiola。 ↩︎

  10. 源自他稱。未辨明現今「臺灣」與「琉球群島」。 ↩︎

  11. 古布立吞語 *kömroɣ。 ↩︎

  12. 「外」字為意譯。 ↩︎ ↩︎

  13. 構擬古代詞形 *čaqa < *ǰaqa。 ↩︎

  14. 古高地德語 Sahso。 ↩︎

List of Transliterations of Biblical Figure Names

Last updated on Thursday, October 1, 2026

This page is still work in progress, stay focus for continuous upcoming updates on this page!

本文之「初唐音系」及「宋代音系」,除引用唐代景教文獻或近代聖經譯名者,皆為自造。

原文發音/擬音初唐音系宋代音系現代天主教通行譯名現代新教通行譯名
אָדָם/ʔaːˈdaːm/阿曇
烏曇頞式䞿柰方音
亞澹亞當亞當
אַהֲרֹן/ʔah(a)ˈroːn/阿輪、阿訶輪亞倫亞郎亞倫
אֵלִיָּה(וּ)/ʔeːliːˈjaːh(uː)/伊利耶唐代景教文獻
翳梨瑜頞式䞿柰方音
逸利耶厄里亞以利亞
אֱלִישֶׁבַע/ʔeːliːˈʃabʕ/ > /ʔɛliːˈʃɛbɑʕ/伊梨奢婆
翳梨娑襒、翳梨邪襒西方方音
逸利舍杷依撒伯爾以利沙伯
בר תלמי/bər tʰɔlˈmaj/鉢達梅、鉢脫梅孛脫買巴爾多祿茂巴多羅買
גַּבְרִיאֵל/gabriːˈʔeːl/笈弼梨噎、笈毘梨噎加俾額爾加百列
דְּבוֹרָה/dVboːˈraː/蝶菩羅底波拉德波辣底波拉
דָּוִד/daːˈwiːd/陀位、陶位
屠越頞式䞿柰方音
多惠唐代景教文獻
大衞、大勿?達味大衞
דָּנִיֵּאל/daːniːˈjeːl/檀尼噎、檀涅
屠尼噎、屠涅頞式䞿柰方音
那寧逸唐代景教文獻
但涅達尼爾但以理
זְכַרְיָה/zakarˈjaːh/邪揭離、邪歇離
刪河律唐代景教文獻
撒迦利亞匝加利亞撒迦利亞
חַוָּה/ħawˈwaː/蒿和、訶和
幺和、翳婆西方方音
夏娃厄娃夏娃
חַנָּה/ħanˈnaː/頇那
安那西方方音
哈拿、安娜亞納哈拿
טוֹבִיָּה/tˤoːbiːˈjaːh/都毘耶
低毘耶頞式䞿柰方音
多比亞多俾亞多比
יְהוֹיָקִים/jahoːjaːˈqiːm/瑜耶謙
瑜阿歆、瑜阿欽西方方音
約耶金若亞敬、伊阿基姆約雅敬
יְהוֹשֻׁעַ/jahoːˈʃuːʕ/瑜首
移蘇、伊蘇西方方音
移鼠、翳數唐代景教文獻
約書亞若蘇厄約書亞
יוֹאֵל/joːˈʔeːl/瑜逸約逸岳厄爾約珥
יוֹחָנָן/joːħaːˈnaːn/瑜罕難唐代景教文獻
瑜頇、瑜安西方方音
銳軒媆頞式䞿柰方音
約翰若望約翰
יוֹנָה/joːˈnaː/瑜那
銳那頞式䞿柰方音
約拿約納約拿
יְהוֹנָתָן
יוֹנָתָן
/jahoːnaːˈtaːn/
/joːnaːˈtaːn/
瑜那灘
銳那孫頞式䞿柰方音
約拿單約拿單
יוֹסֵף/joːˈseːp/瑜燮
銳燮頞式䞿柰方音
若瑟約瑟
יַעֲקֹב/jaʕˈqoːb/耶佮
耶劫西方方音
揚劫頞式䞿柰方音
耶佮雅各伯雅各
יִצְחָק/jisˤˈħaːq/逸司郝、以索
逸茲郝、伊即頞式䞿柰方音
以索、以撒依撒格以撒
יֶרֶד/jard/ > /ˈjɛrɛd/曳戾耶列耶勒得雅列
יִשַׁי/jiˈʃaj/逸籭逸籭葉瑟耶西
יִשְׂרָאֵל/jiɬraːˈʔeːl/肄羅噎
肄盧噎頞式䞿柰方音
以色列
מִיכָאֵל/miːkaːˈʔeːl/彌佉逸、彌訶逸
彌呼逸頞式䞿柰方音
彌沙曳唐代景教文獻
彌額爾米迦勒
מִיכָה/miːˈkaː/彌佉、彌迦、彌訶
彌虛頞式䞿柰方音
彌迦米該亞彌迦
מִרְיָם/mirˈjaːm/末閻
末豔唐代景教文獻
瑪利亞、馬利亞瑪利亞馬利亞
מֹשֶׁה/moˈʃɛ/謨籭
謨西西方方音
梅籭頞式䞿柰方音
牟世唐代景教文獻
梅瑟摩西
מַתַּי/maˈtaj/末帶
明泰唐代景教文獻
馬太瑪竇馬太
נָתָן/naːˈtaːn/那灘
奴孫頞式䞿柰方音
拿單、那灘拿單
עָמוֹס/ʕaːˈmoːs/阿慕司、阿沒司、阿昧阿摩司亞毛斯阿摩司
רְאוּבֵן/rVʔuːˈbeːn/盧甌駢勒烏本流便、呂便
רִבְקָה/ribˈqaː/立哥
立鷿迦西方方音
立居頞式䞿柰方音
立加、利百加黎貝加利百加
שְׁמוּאֵל/ʃVmuːˈʔeːl/睒牟噎
三牟噎西方方音
濕牟噎新東方方音、頞式䞿柰方音
三繆撒慕爾撒母耳
שִׁמְעוֹן/ʃimˈʕoːn/深門
岑穩唐代景教文獻
深門、西門西滿西門
שָׂרָה/ɬaːˈraː/娑羅
蘇羅頞式䞿柰方音
娑拉撒辣撒拉
תְּאוֹמָא/təʔoːˈmɑːʔ/島摩刀馬多默多馬
Ἀνδρέᾱς/anˈdreaːs/安滯安突利安德肋安德烈
Λουκᾶς/luːˈkaːs/盧迦
盧伽唐代景教文獻
路加路加路加
Παῦλος/ˈpaulos/褒盧
寶路唐代景教文獻
保羅保祿保羅
Πέτρος/ˈpetros/篦株、閉株別突伯多祿彼得
Τῑμόθεος/tiˈmotʰeos/低末挑低末眺弟茂德提摩太
Mārcus/ˈmaːrkus/末厥司、末貴
摩矩辭唐代景教文獻
末骨思馬爾谷馬可

Minecraft Pentaglot

真的能看見湊齊的一天了?

⚠️ Notice

This post is a draft translation from the Chinese version which have not yet been thoroughly proofread.

  • 漢語:早就有了。現在有四個變體:中國、台灣、香港、文言。
  • 蒙古語:目前有西里爾蒙文,不過我發現若干地方似乎有校對失誤。例如「深板岩紅石礦」被翻成 гүний занар дахь улаан чулууны хүдэр,但是別的紅石大多是譯成 редстоун,而事實上「紅石」一詞在 Mojang 欽點必用音譯的清單裏頭;又例如 magenta 通常被譯成 ягаан 而 pink 通常被譯成 цайвар ягаан,但是兩種顏色的床居然都寫成了 ягаан ор。
  • 維吾爾語:Crowdin 上現有的維吾爾語項目完成度其實不低,也許只差個審核員……
  • 藏語:最近有人剛剛發起了,正在徵求合用的審核員當中。
  • 滿語:好像還沒有人做。

BlogBlog Party: Acquisition, Transmission, and Promotion of Languages (October 2026)

⚠️ Notice

This post is a draft translation from the Chinese version which have not yet been thoroughly proofread.

I already had a plan to become a BlogBlog Party host back in March 2026, with my slot originally scheduled right after ikuka. However, due to a busy work schedule in September, I postponed the hosting timeslot by a month to October.

One of the reasons for this website’s existence is to archive various easy-to-read notes, including, but not limited to, material on language learning and promotion. While the site currently features quite a lot articles on linguistics, my actual professional background is completely unrelated to the field in fact.

You may have noticed that this website is actually multilingual, although I often publish a version in one language first and gradually translate it into the others much later when I have time.

Theme: “Acquisition, Transmission, and Promotion of Languages”

The theme of October 2026 is: “Acquisition, Transmission, and Promotion of Languages”!

In light of the decline of native languages1, what are your thoughts, opinions, or suggestions? In fact, “Development and Preservation of Native Languages](#-development-and-preservation-of-native-languages)” is the topic I originally drafted.

Side note: Speaking of local languages, it seems difficult to find online learning materials for (Taiwanese) Hokkien suitable for foreigners with zero prior knowledge, and related natural language processing systems are still in the development stage. Perhaps this represents a significant gap in the market. I might consider developing a proprietary teaching platform for it in the future.

Topic Ideas

Here are some topic ideas for your reference.

💬 Development and Preservation of Native Languages

This is the title I originally drafted. After discussing it with others, I felt the initial title was a bit too narrow, so I broadened it to its current form.

  • 👨‍👩‍👧‍👦 Language policies at the family and societal levels: “If” you plan to start a family and have children, what kind of language policies do you intend to implement within your family, with your children, and in your community?
  • 🗳️ Government-level language policy: Suppose you had the authority to formulate policy at the government level, what kind of language policy would you establish for your citizens?
  • 💬 Discussion about the orthography, expressions, and idioms in the native language?: If I were to actually write about it, I could probably create an entire category of articles. It’s just that, right now, I’m a bit too lazy to get started.
  • 👴 Seeking Roots: The personal journey of reclaiming an ancestral language following a linguistic break?
  • 🏴🏫 Extreme Linguistic Revitalizationism: Imagine a post-World War III world. If you were a child in this era, sent by political zealots to a “native language school” where you were forced to receive native language education, (possibly with every subject taught in that native language), would you feel distressed, struggle to keep up with your studies, and eventually come to hate school? What if adults who lacked proficiency in the native language were even forced to undergo “re-education” simply because the original national language was branded the tongue of the colonizers?
  • 💻 Natural Language Processing for Low-Resource Languages: 這是一個比較偏向技術層面的面向。一些本土語言的自然語言處理技術發展較晚,各位對此有無建議?可能的實作方向或者產品都可以。各位如何投資本土語言/低資源語言的語音合成與辨識、斷詞、標音、翻譯、TTS/RVC 音源等技術?
  • 🩸🔫🙊😱 還是說,比起本土語言的保育,你更樂於以強勢語言打壓及侮辱本土語言?

🌐 Comments about Language Policies of Governments Around the World

Commentary on the language policies of various governments. This may cover historical policies or those currently in effect.

📚 Experience of Language Learning

  • 💬 你是否曾經有被要求學習多種語言,然後發現學習進度根本追不上的經驗?
  • 💬 你最喜歡的語言、學過的語言、最想學的語言、學了很久還是學不好的語言?
  • 🧑‍🏫 遇到過的語言老師、交過的不同語言的朋友
  • 📚 自己私藏的語言學習法

❓ Miscellaneous

  • 🗣️ 因為語言/口音不同而發生的趣事、culture shock 或者歧視經驗
  • 🐱 跟寵物溝通的語言、使用不同語言(甚至程式語言)的經驗
  • 💡 各種有關語言的冷知識,似乎和幾個月前的同樂會主題有點兒重疊(但我不會禁止在往期同樂會投稿過的舊文重複投稿!)。

以上提示僅供參考,參與者可以自由發揮,只要內容和「Acquisition, Transmission, and Promotion of Languages」有關即可。

參加方式

  1. 在自己的部落格上寫一篇跟「Acquisition, Transmission, and Promotion of Languages」有關的文章(可以的話,複製下方的文字放在文章開頭,但不強制)

    📝 在投稿文章開頭放這段文字(非強制)

    This is my submission article for “BlogBlog Club Party - October 2026”. This month’s topic is “Acquisition, Transmission, and Promotion of Languages”, hosted by AngeCI. If you have your own blog, feel free to join us together!

    如果你用 markdown 語法寫作,可以直接複製下行:

    > This is my submission article for “[BlogBlog Club Party - October 2026](https://blogblog.club/party)”. This month’s topic is “[Acquisition, Transmission, and Promotion of Languages](https://angeci.github.io/blog/zh/blogblog-party-languages/)”, hosted by [AngeCI](https://angeci.github.io/blog/). If you have your own blog, feel free to join us together!
    
  2. 把文章連結(不是全文喔)寄到我的信箱 angeci (at) ltgc.cc 2

  3. 信件主旨可寫「BlogBlog 同樂會投稿:Acquisition, Transmission, and Promotion of Languages」

    信件內文參考格式:

    [文章名稱](https://blog-post-url) - 投稿人稱呼
    
    投稿附言(可選)
    

    如果您投稿時沒有向本人清晰指明投稿人稱呼的話,我會嘗試從往期投稿名單尋找配對。要是配對不了的話我就可能只能從電郵標頭或部落格標題隨便亂抓了。

  4. 記得在截稿日(2026-10-31)3前寄出!(即日起就可以開始投稿)

Q & A

  • Q1: 沒有自己的部落格也能參加嗎?

    A1: 如果是「自己」的部落格更好。但文章如果是在 Substack、Medium、方格子也 OK。不接受社群媒體的投稿(如 Facebook、Instagram、Threads、X)。請確保投稿文章在截稿時公開可見。如果我在中途或截稿時發現文章無法公開檢視的話,我會嘗試通知有關的投稿者,一段時間之內沒有恢復/更新的話我會把失效/無法檢視的連結直接移除。

  • Q2: 一定要寫新文章嗎?可以拿之前寫的舊文章參加嗎?

    A2: 可以拿過去的舊文章參加唷!如果你部落格裡剛好有符合主題的文章,可以直接投稿,不用因為文章是去年寫的就不好意思拿出來。只要符合「Acquisition, Transmission, and Promotion of Languages」這個主題的文章都可以參加。(但為同樂會專門寫一篇新的文章,會更有參與感喔!)

  • Q3: 投稿有篇數上限嗎?

    A3: 原則上不設限4,這可能是歷屆同樂會以來最佛心的一次了 ,但也請別刻意灌水滋擾我拜託🤣。

  • Q4: 投稿語言有限制嗎?

    A4: 原則上無限制,不過 BlogBlog 同樂會的投稿活動一般以繁體中文為主。視乎本人對不同語種的熟悉程度,我有可能需要依賴機器翻譯服務來理解閣下的外語投稿。不過本人台語程度較弱5,若閣下投稿「只」有台語的文章而未有提供翻譯(翻譯要公開或者私下提供都可以),我將會需要依賴機器翻譯服務輔助理解。

  • Q5: 投稿後多久會收到回覆?6

    A5: 儘可能在一至兩天內回覆吧7。如果我剛好比較沒空或是您在臨近截稿期限時投稿的話,我可能會先出一封回信確認收件,之後才另外補上針對文章內容的回應(或者直接在回顧文中回覆)。您亦可以隨時造訪本頁的投稿文章列表檢查本人是否已確認收件。但我目前用的是免費郵箱服務,不保證回顧文發佈時會給大家統一發 newsletter。

  • Q6:投稿名單多久會更新一次?

    A6:在初期文章不太多的時候,我可能會積攢夠一定的篇數或者等到部落格有其他內容更新的時候才一併更新這裏。但我會盡快回覆郵件確認收件。到後期投稿速度變高的時候我想我就會每天更新這裏的投稿名單了,除非有哪天我不太有空。

  • Q7:可不可以投稿立場較為偏激嘅文章?

    A7:我不會自動拒絕立場偏激嘅文章投稿,但我可能會喺文章連結側邊標示立場激進,請各位讀者做好心理準備。與本人立場相左的文章可能會被我在回顧文中以嘲諷的口吻敘述,後果自負。

已經投稿的作者清單(持續更新)

活動期間,這裡會持續更新已投稿的文章連結,歡迎大家互相閱讀、交流、訂閱!最終整理與回顧文章會在 11 月初發布。

以下是目前參與文章的連結列表(按投稿順序):

  1. A Brief Discussion on Several Chinese Dialectal Phenomena - AngeCI
  2. Importance of Studying Classical Chinese - AngeCI
  3. About Chinese Calligraphy Education - AngeCI
  4. Multilingual Blog - AngeCI
  5. Unifying Names - AngeCI
  6. Alex Hsu Suppresses Local Languages - AngeCI
  7. 二十年前部落格圈的簡體繁體議論 - 我
  8. 有關片名翻譯的問題3 - 我
  9. 失語症患者重新學會說話,算是重新學一種語言嗎? - 神經沒問題
  10. 跌跌撞撞的台語學習歷程 - Wen
  11. 學「台語」,真的好嗎?(偏激A版、偏激B版、中性版) - Tommy
  12. 親切與親切 - Tomo
  13. 谁有资格被称作台湾台语 - Eddie Lv

Last update: 2026-10-05


  1. 別以為是只有台灣是這樣,其實大陸甚至香港都有。 ↩︎

  2. 請注意,本人用於發送回郵的電郵地址將與接收郵件的地址不同。各位要再回覆郵件的話,可以在兩個郵件地址之間任擇其一。 ↩︎

  3. 由於「BlogBlog 同樂會主持人手冊」裏面沒有指明截稿日所依據的時區,我可能會從寬認定。目前地球上正在使用的最晚的時區是 UTC-12,比台灣時間晚了 20 小時,我個人的截稿時間可能以這個為準,稱作 AoE(anywhere on earth)時間(順帶一提最早的時區是 UTC+14)。如果閣下在截稿時間過後、回顧文發佈前投稿,我有可能會接受閣下的逾期投稿,但不保證我會趕及在回顧文發佈前將閣下的逾期投稿整理進去。 ↩︎

  4. 但是不排除會因為本人的突發事件而收緊。 ↩︎

  5. 本人是香港人,我家也沒有祖籍是閩南或者潮汕的親戚,因此閩南語其實不算是我的 heritage language8,我也不會有在童年自然習得閩南語的環境。我僅有的閩南語能力都是在我長大之後基於對外語的興趣才開始學習的。 ↩︎

  6. 對,我就是個比較急性子的人。我比較喜歡可以掌控一切的感覺,而不太喜歡無了期等待的不確定性。 ↩︎

  7. 如果我長時間未有回覆閣下的郵件,而我又有將閣下的投稿更新到投稿列表中,那你大概率是幹了什麼齷齪事讓我選擇刻意延遲回覆了。同理,如果你提交原文是繁體,但本頁列出的文章標題被強制轉換成簡體的話,那麼你可以好好思考一下你做了什麼讓我決定這麼做。 ↩︎

  8. 其實香港人祖籍在潮汕或閩南的比例其實不低(但不至於壓倒性優勢),但我自己剛好不是。實際上香港中老年人能講這些 heritage langauge 的比例已經不多,年輕一代連聽懂都成問題。有關香港的語言發展史,我日後也許會再出一篇專題文章。 ↩︎

Transliteration Guide for Tang Dynasty Chinese

Last updated on Monday, September 14, 2026
🚨 Caution

This article about discussion on the Chinese language itself and is not translated in to English yet (and probably never), please refer to the Chinese version instead.

This page is still work in progress, stay focus for continuous upcoming updates on this page!

聲母

  • क ख ग घ → 見組三等。見組非三等在中古早期一般構擬為小舌音,不用於音譯梵語。中國北方的各種「胡語」當中有小舌音,確實會拿見組非三等字來對譯。
  • च छ ज झ → 章昌常;ज्ञ 一般用日母字去對。
  • ट ठ ड → 知組。
  • त थ द ध → 端組。
  • ण न → 泥母或娘母都可以。
  • प फ ब भ म → 幫組,不分輕重脣。
  • य 用以母;व 用輕唇音字、匣母合口或云母,偶有見重唇音。
  • र ल 都用來母去對。
  • श ष स 分別用書母、生母、心母。ह 用曉母。
  • क्ष /(k)tʂʰ/,中古漢語一般用初母來對。
  • 梵語的濁送氣輔音,用中古漢語的全濁聲母去對,即與梵語的濁不送氣輔音相同。
  • f 盡量用後世輕唇音字對應?

韻母

  • 3C 介音還在正在產生的過程當中,在音譯外語中常常約等於無。
  • ti di 等音節,通常對以「提、帝」等齊韻字,「地」字也可以用,偶有見用舌上音聲母遷就的。

梵漢對音音節表

kkhg/ghcchj/jhjñ
a/ā迦佉伽遮闍左車闍社若惹
i/ī枳基祇耆支只
u/ū鳩俱拘丘邱瞿周殊
e/āi計稽基制逝
o/āu拘瞿驕喬瞿
am/aṁ劒今嚴占閻
ap劫罽
an/aṇ犍彥檀旃禪
at/aṭ/ar/al羯揭
in/iṇ真
un/uṇ捃均
ut/uṭ/ur/ul掘
∅乞
ṭṭhḍ/ḍhṇ
a/ā吒吒荼那
i/ī知胝遲池持尼
tthd/dhn
a/ā多他陀陀馱郍那拏
i/ī帝底提地尼
u/ū/o/āu都度奴怒𠯆
∅怛呾達達
pphb/bhm
a/ā波播坡叵婆摩磨麼
i/ī毘彌弭
u/ū布補浮菩牟畝
an/aṇ般畔
∅鉢
yr/lvśṣsh∅
a/ā耶也夜羅囉邏和婆縛沙舍娑訶賀阿
i/ī利梨韋毘尾施始師斯私伊
u/ū臾由盧首戍蘇素
e/āi吠曀
o/āu瑜喻魯路侮
am/aṁ焰覽蘭三僧散
ak洛釋塞
∅施室濕師瑟斯私悉迄紇

例子

以下是一些後起或現今某社群自造的譯名:

  • Sverige /ˈsværjɛ/ → 遂歷:zy̯i(s) lek → zyi liʔ ✖
    • 在宋代音系中「遂歷」可以成立,但初唐音系不能。聲母清濁需要嚴格分清。
  • Sverige /ˈsværjɛ/ → 眭璃:sy̯e li̯e → syi li ✔
  • 古諾爾斯語 sví- /swiː-/ → 綏(國):sy̯i (qʷək) → syi (kuəʔ) ✔❔
  • 古諾爾斯語 sven- /swen-/ → 宣(國):sy̯ɛn (qʷək) → syɛn (kuəʔ) ✔❔
  • Deutsch /dɔɪt͡ʃ/ → 隤䲭:dʷʌi̯ tɕʰi → duɔi tʃʰi ✔
  • France → 法蘭西:pʉ̯ɜp lɑn se(i̯) → fɑp lan si ⭕️
    • 也許第一個字改成「弗」/pʉt/?
  • English → 英吉利:ʔɪ̯aŋ kit li(s) → ʔiŋ ciɾ li ✔
  • Italia → 有犢:ɨ̯u(ʔ) duk → iəu duʔ ✖
    • 發音依據不明,而且與「有毒」諧音?
  • Italia → 意大利:ʔɨ(ç) dɑi̯ li(s) → ʔi dɑi li ✖❔
  • Italia → 伊多梨:ʔi tɑ li → ʔji tɔ li ✔
    • 有意見認為「Italia」中間那個音節應對以歌韻字。
  • American → 美利堅:mɪ(ʔ) li(s) qen → mi li ciɛn ✖
  • America → 阿蔑梨迦:ʔɑ met li kɨ̯ɑ → ʔɔ m(ʲ)iɛɾ li (k/c)iɛ ✔
  • America → (阿)彌梨迦:ʔɑ mi̯e li kɨ̯ɑ → (ʔɔ) m(ʲ)i li (k/c)iɛ ✔
  • American → (阿)彌梨犍:ʔɑ mi̯e li kɨ̯ɜn → (ʔɔ) m(ʲ)i li (k/c)iɛn ✔
    • 在初唐音系,硬腭音和小舌音不能混淆(除非無字可用),而小舌音一般不見於近代以前的歐洲語言。
  • Stockholm → 士多貢:dʐɨ(ʔ) tɑ quŋ(h) → ʐʅ tɔ kuŋ ✖
  • Stockholm → 司拓堪:sɨ tʰɑk qʰʌm → sɿ tʰɔʔ kʰɑm ✔
  • Stockholm → 司篤堪:sɨ tok qʰʌm → sɿ tuʔ kʰɑm ✔
    • /kʰɨ̯ɜm/ 無常用字可用,以 /qʰʌm/ 妥協之。
  • Portugal → 埠吐噶:bo(h) tʰo(h) *qɑt → bu tʰu kɑɾ ⭕️
  • Brazil → 枋林:pʉ̯ɑŋ lim → fɑŋ lim ✖
  • Brazil → 拔囚:bʵɛt zɨ̯u → baɾ ziəu ✔
    • /bʵat/ 無字可用,以 /bʵɛt/ 妥協之。
  • Україна → 渥蓮:ʔʵʌu̯k len → ʔjɔʔ liɛn ✖❔
  • Україна → 屋冷:ʔuk lʵaŋ → ʔuʔ ləŋ ⭕️❔
    • 有人將梗攝和曾攝擬作 -ɲ 韻尾,於是也可以拿來對譯「烏克蘭」了。
  • Україна → 屋家寅:ʔuk qʵa jin → ʔuʔ ca jin ⭕️❔
  • Україна → 屋扢賴寅:ʔuk kɨt lɑi̯ jin → ʔuʔ kiɾ lai jin ✔
    • 烏克蘭歷史上也被稱作「小俄羅斯」,或可作「小羅剎」。不過放在現在的地緣政治形勢,這名字恐怕有些人在政治層面接受不了。
  • España → 士班雅:dʐɨ(ʔ) pʵan ɴʵaʔ → ʐʅ pan ɲa ✖
  • Hispānia → 司般若:sɨ p(u)ɑ(n) ȵi̯a(ʔ) → sɿ p(u)ɔ(n) ȵiɛ ✔
  • Hispānia → 司波尼:sɨ p(u)ɑ ɳi → sɿ p(u)ɔ ni ✔
  • Venezuela → 駢迡血羅:ben ne(i̯)(ç) χʷet lɑ → b(ʲ)iɛn ni çyɛɾ lɔ ✖
    • 第三個音節尖團不分?
  • Albania → 遏婆如:ʔɑt b(u)ɑ ȵɨ̯ɤ → ʔɑɾ b(u)ɔ ȵ(y/iu) ⭕️
  • Bosna i Hercegovina → 蒲娑那與褉績劬毗那:bo sɑ nɑ jɤ χet tsek gɨ̯o bi nɑ → bu sɔ nɔ j(y/iu) çiɛɾ tsiʔ (g/ɟ)(y/iu) b(ʲ)i nɔ ✔
  • Чуваш → 櫧旆:tɕɨ̯ɤ bɑi̯ → tʃ(y/iu) b(u)ɔi ✔❔
  • Чуваш → 諸衞師:tɕɨ̯ɤ ɰʏ̯ɛi̯ ʂɪ → tʃ(y/iu) wei ʂʅ ✔❔
  • Чуваш → 諸會師:tɕɨ̯ɤ ʁʷɑi̯ ʂɪ → tʃ(y/iu) ɣui ʂʅ ⭕️❔
  • Aztec → 阿辭的:ʔɑ zɨ tek → ʔɔ zɿ tiʔ ✔
  • Graham → 偈含:gɪ̯ɛi̯ ʁʌm → (g/ɟ)i ɣam ❔
  • Baroque → 婆醁(風):b(u)ɑ lɨ̯ok (p(ɨ̯uŋ/ʉŋ)) → b(u)ɔ luʔ (fuŋ) ✔
  • Cotán → 拘丹:kɨ̯o tɑn → (k/c)(y/iu) tan ✔
  • Dennis → 田迡:den ne(i̯)(ç) → diɛn ni ✔
  • Alex → 遏戾:ʔɑt le(i̯)(s) → ʔɑɾ li ⭕️
  • Efe → 易譬:je(ç) pʰi̯e(ç) → ji pʰ(ʲ)i ⭕️
  • Steve → 悉涉:sit tep → siɾ tiɛp ⭕️
  • Persson /ˈpæːʂɔn/ → 陂兒宋:pɪ̯e ȵi̯e soŋ(h) → pi ȵi suŋ ✖
  • Persson /ˈpæːʂɔn/ → 派雙:pʰʵɛ(h) ʂʌu̯ŋ → pʰa(i) ʂɑŋ ✔
    • /ʂɤn/ 無字可用,有多種妥協辦法。
  • Zetterstrand /ˈsɛtːɛʂˌʈrand/ → 截瀦悉蘭:dzet ʈɨ̯ɤ sit lɑn → dziɛɾ tʂu siɾ lan ✖
  • Zetterstrand /ˈsɛtːɛʂˌʈrand/ → 截致丹:dzet ʈɪ(s) tɑn → dziɛɾ tʂʅ tan ✖
    • 瑞典語中只有前面跟着 r 的 d t n l s 才是捲舌音。此例中「瀦致」均被用於對應平舌音 tt,可以對應為翹舌音的 rstr 反而用了平舌音。
  • Åberg /ˈoːbærj/ → 亞伯:ʔʵa(h) pʵak → ʔja pəʔ ✖
  • 古諾爾斯語 á + berg /ˈɑːberg/ → 亞伯:ʔʵa(h) pʵak → ʔja pəʔ ⭕️❔
  • עִבְרִית /ʕiβˈriːθ/ → /(ʔ)ivˈʁit/ → 挹栗:ʔip lit → ʔjip liɾ ⭕️❔
    • ע 這個字母的古代希伯來語發音,很不像中古漢語的影母,可能更像云母或匣母。也許可以改成「瞱栗」或者「瞱梨」。
  • 英語 Hebrew 或教會拉丁語 hebræus /eˈbrɛːus/ → 協婁:ʁep ləu̯ → ʝiɛp ləu ✖❔
  • guitar → 耆撻(琴):gɪ tʰɑt (gɪm) → (g/ɟ)i tʰɑɾ ((g/ɟ)im) ✔
  • didgeridoo → 地蜍梨頭(管):di(ç) dʑɨ̯ɤ li dəu̯ (qʷɑn(ʔ)) → di dʒ(y/iu) li dəu (kuɔn) ✔

以下是一些出自唐代景教文獻的譯名:

  • Μᾶρκος Mārcus → 摩矩辭:m(u)ɑ kɨ̯o(ʔ) zɨ → m(u)ɔ (k/c)(y/iu) zɿ
  • 亞蘭語 מַתַּי /maˈtaj/ → 古希臘語 Ματθαῖος Matthæus → 明泰:mɪ̯aŋ tʰɑi̯ → miŋ tʰɑi
    • 唐宋西北方音鼻音韻尾可能有脫落的傾向?
  • Παῦλος Paulus → 寶路:pɑu̯(ʔ) lo(h) → pɑu lu
  • Γεώργῐος Georgius → 宜和吉思?:ŋɪ̯e ʁʷɑ kit sɨ → ɲi ɣuɔ ciɾ sɿ
  • Γεώργῐος Georgius → 藝利月思?:ŋi̯ɛi̯ li(s) ŋʉ̯ɜt sɨ → ɲi li (ŋ/ɲ)yɛɾ sɿ
    • 鼻音變成濁塞音,是唐宋西北方音的特徵。
  • יוֹחָנָן /joːħaːˈnaːn/ → /joχaˈnan/ → 瑜罕難:jɨ̯o χɑn(ʔ) nɑn(h) → j(y/iu) xan nan
  • דָּוִד /daːˈwiːð/ → /daˈvid/ → 多惠:tɑ ʁʷe(i̯)(s) → tɔ ɣui
    • 詞末的 /d/ 弱化成 /ð/,漢音或忽略。
  • דָּנִיֵּאל /daːniːˈjeːl/ → /daniˈjel/ → 那寧逸?:nɑ neŋ jit → nɔ niŋ jiɾ
    • 鼻音變成濁塞音,是唐宋西北方音的特徵。
  • שִׁמְעוֹן /ʃimˈʕoːn/ → /ʃimˈ(ʔ)on/ → 岑穩:dʐim ʔʷon(ʔ) → dʐim ʔuən
  • מִיכָאֵל /miːxaːˈʔeːl/ → /miχaˈ(ʔ)el/ → 彌沙曳?:mi̯e ʂa jɛi̯ → m(ʲ)i ʂa ji
  • זְכַרְיָה /zəxarˈjaːh/ → /zeχaʁˈja(h)/ → 刪河律:ʂʵan ʁɑ lyt → ʂan ɣɔ lyɾ
  • אֵלִיָּה(וּ) /ʔiliːˈjaːh(uː)/ → /(ʔ)eliˈja(hu)/ → 伊利耶:ʔi li(s) ja → ʔji li jɛ

Transliteration Guide for Song Dynasty Chinese

Last updated on Sunday, September 6, 2026
🚨 Caution

This article about discussion on the Chinese language itself and is not translated in to English yet (and probably never), please refer to the Chinese version instead.

This page is still work in progress, stay focus for continuous upcoming updates on this page!

聲母

音系構擬

本文假設:

  • 知照已經合流。
  • 牙喉音分為腭化與非腭化兩組。這一項對於音譯外語來說不是那麼的重要,但是能解釋一些更後來的《中原音韻》和《蒙古字韻》中的對立小韻。
  • 我目前選擇保留中古濁音聲母,但畢竟在宋代濁音清化都在進行中了,因此這不是必須嚴守的定律。
唇音齒音/齦音舌尖後音齦後音硬腭音軟腭音聲門音
不送氣清塞音幫 /p/端 /t/見 /c/見 /k/影 /ʔ/
送氣清塞音滂 /pʰ/透 /tʰ/溪 /cʰ/溪 /kʰ/
濁塞音並 /b/定 /d/羣 /ɟ/羣 /g/
鼻音明 /m/泥娘 /n/疑 /ɲ/疑 /ŋ/
不送氣清塞擦音精 /ts/知二莊 /tʂ/知三章 /tʃ/
送氣清塞擦音清 /tsʰ/徹二初 /tʂʰ/徹三昌 /tʃʰ/
濁塞擦音從 /dz/澄二崇 /dʐ/澄三常 /dʒ/
清擦音非敷 /f/心 /s/生 /ʂ/書 /ʃ/曉 /ç/曉 /h/ ~ /x/
濁擦音奉 /v/邪 /z/ ~ /dz/崇俟 /ʐ/ ~ /dʐ/常船 /ʒ/ ~ /dʒ/匣 /ʝ/匣 /ɣ/
邊音/近音微 /ʋ/來 /l/日 /ȵ/ > /ɻ/以 /ji/云 /j/

音譯原則

  • 區分平翹、尖團。
    • Lisa → 立夏 lip ça ✖
    • Nasim → 捺心 nɑɾ sim ✔
    • Nasim → 納棎 nɑp ʒiɛm ✖
    • Zetterstrand /ˈsɛtːɛʂˌʈrand/ → 截瀦悉蘭 dziɛɾ tʂu siɾ lan ✖
    • Zetterstrand /ˈsɛtːɛʂˌʈrand/ → 截致丹 dziɛɾ tʂʅ tan ✖
    • Zetterstrand /ˈsɛtːɛʂˌʈrand/ → 截突譠 dziɛɾ tʰuəɾ tʂan ✔
      • 瑞典語中只有前面跟着 r 的 d t n l s 才是捲舌音。此例中「瀦致」均被用於對應平舌音 tt,可以對應為翹舌音的 rstr 反而用了平舌音。
    • Zając /ˈzajɔnt͡s/ → 紗藥 ʂa jiɔʔ ✖
      • 第一個音節平翹不分;第二個音節誤判原音。
    • España → 士班雅 ʐʅ pan ɲa ❔
      • 「士班雅」一名始見於清代《聖經》譯本,能否符合宋代音系成疑。
    • Castilla → 干係臘 kan çi lɑp ✖
      • 此名見於《明史》,尖團已經不分。尖團聲母在現代粵客閩方言的聽感差異極大,如果要對應宋代音系的話,寧願捨棄其他部份也最好保全尖團。明代的其他文獻有「乾絲臘」、「乾絲蚋」等譯名。
  • 牙喉音聲母不區分三等與非三等,與初唐音系有異。
  • 「兒爾」等字在宋代的發音大概是 /ȵi/,變成 /ɚ/ 是明代的事了。

韻母

音系構擬

本文假設:

  • 假攝、遇攝已經高化:合於各現代漢語方言,異於各域外方音。不過某些歌韻字直到現代都還沒高化仍維持類似 /a/ 的發音,音譯時容許靈活處理。
  • 蟹止已經合流:合於大部份現代漢語方言,異於閩南語文讀與粵語。
  • 梗曾已經合流:合於大部份現代漢語方言,異於粵客贛方言。
  • 介音採用近代漢語的「四呼」體系,不使用韻圖的「四等二呼」體系。
  • 宋代入聲實際押韻狀況混亂。此處假設 -k 為 -ʔ、-t 為 -ɾ、-p 不變。
a ~ ɛəiɔu
-∅麻遮開 /a/支思開 /ɿ/歌戈開 /ɔ/
u-∅麻遮合 /ua/齊微合 /ui/歌戈合 /uɔ/魚模合 /u/
i-∅麻遮齊 /iɛ/齊微齊 /i/
y-∅麻遮撮 /yɛ/齊微撮 /yi/魚模撮 /iu/ ~ /y/
-i皆來開 /ɑi/
u-i皆來合 /uai/灰杯合 /-uɔi/
-u蕭豪開 /ɑu/尤侯開 /əu/
i-u蕭豪齊 /iau/尤侯齊 /iəu/
a ~ ɑiɑ ~ iɛəi ~ iəɔ, uiu
-m鹽咸開 /am/鹽咸齊 /iɛm/侵尋開 /əm/侵尋齊 /im/ ~ /iəm/
-n寒先開 /an/寒先齊 /iɛn/真文開 /ən/真文齊 /in/ ~ /iən/
u-n寒先合 /uan/寒先撮 /yɛn/真文合 /uən/真文撮 /yən/桓歡合 /uɔn/
-ŋ江陽開 /ɑŋ/江陽齊 /iɑŋ/庚青開 /əŋ/庚青齊 /iŋ/ ~ /iəŋ/
u-ŋ江陽合 /uɑŋ/江陽撮 /yɑŋ/庚青合 /uəŋ/庚青撮 /yŋ/ ~ /yəŋ/東鍾合 /uŋ/東鍾撮 /iuŋ/ ~ /yuŋ/
ɑiɑ ~ iɛəi ~ iəɔiɔuiu ~ y
-p葉洽開 /ɑp/葉洽合 /iɛp/緝習開 /ip/ ~ /iəp/
-ɾ曷屑開 /ɑɾ/曷屑齊 /iɛɾ/質物開 /əɾ/質物齊 /iɾ/ ~ /iəɾ/
u-ɾ曷屑合 /uɑɾ/曷屑撮 /yɛɾ/質物合 /uəɾ/質物撮 /yɾ/ ~ /yəɾ/
-ʔ陌錫開 /əʔ/陌錫齊 /iʔ/ ~ /iəʔ/覺藥開 /ɔʔ/覺藥齊 /iɔʔ/
u-ʔ陌錫合 /uəʔ/陌錫撮 /yʔ/ ~ /yəʔ/覺藥合 /uɔʔ/覺藥撮 /yɔʔ/屋沃合 /uʔ/屋沃撮 /iuʔ/ ~ /yuʔ/

按攝排列:

攝一等二等三四等
果攝開口ɔiɛ
果攝合口uɔyɛ
假攝開口aiɛ
假攝合口ua
遇攝uiu > y
蟹攝開口ɑiɑii
蟹攝合口uɔiuaiui, yi
止攝開口i, ɿ
止攝合口ui, yi
效攝ɑuɑuiau
流攝əuiəu
咸攝am, apam, apiɛm, iɛp
深攝(əm, əp)im, ip
山攝開口an, ɑɾan, ɑɾiɛn, iɛɾ
山攝合口uɔn, uɑɾuan, uɑɾyɛn, yɛɾ
臻攝開口ən, əɾin, iɾ
臻攝合口uən, uəɾyən, yəɾ
宕攝開口ɑŋ, ɔʔiɑŋ, iɔʔ
宕攝合口uɑŋ, uɔʔyɑŋ, yɔʔ
梗攝開口əŋ, əʔiŋ, iʔ
梗攝合口uəŋ, uəʔyŋ, yʔ
曾攝開口əŋ, əʔiŋ, iʔ
曾攝合口uəŋ, uəʔyŋ, yʔ
通uŋ, uʔiuŋ ~ yuŋ, iuʔ ~ yuʔ
江ɑŋ, ɔʔ

音譯原則

  • 不要忽略入聲。
    • Lyrmark → 律麥 lyɾ məʔ ✔
    • Lyrmark → 劉罵 liəu ma ✖
      • 「罵」用字不雅,發音也對不上,建議改成「麥」。
    • Stockholm → 士多貢 ʐʅ tɔ kuŋ ❔
  • 塞音結尾音節盡量(儘管不必嚴守)用同部位或近部位的入聲字來譯。
    • Nederland → 尼德蘭 ni təʔ lan ⭕️
      • 「德」屬於遠部位入聲,也許換成「突」更好。
  • -l, -r 或 -s 結尾的音節,可以用 -t 尾入聲字來譯。
    • Markus → 末骨思 m(u)ɑɾ kuəɾ sɿ ✔
    • Markus → 禡忌於易斯 ma (g/ɟ)i ʔ(y/iu) ji sɿ ✖
  • 入聲字最好不要拿來對應非入聲的音節,除非能把緊隨其後的輔音借來用。
    • Mississippi → 密西西比 miɾ si si p(ʲ)i ✔
    • Mississippi → 密士失必 miɾ ʐʅ ʃiɾ p(ʲ)iɾ ✖
      • 「密士失必」據說出自一本 1980 年代的書籍,與宋代音系無關。
      • 「pi」非入聲音節,也沒有緊隨其後可以借用的輔音。
      • 「士失」皆為翹舌音聲母,不可拿來對應原文的平舌輔音。
      • 現今常用的官話音譯「密西西比」倒是可以符合宋代音譯習慣。

NoScript

Last updated on Monday, August 24, 2026
⚠️ Notice

This post is a draft translation from the Chinese version which have not yet been thoroughly proofread.

有些人習慣預設禁用瀏覽器執行 JavaScript 的權限,甚至對一切含有 JavaScript 的網頁持反感態度。最近讀到了 Spike Leung 的《請開啟 JavaScript 以繼續搜尋》和廢文小天地的《關掉 JS 也沒問題!》。我想提出一些對激進 NoScript 觀點的反駁。

Spike 把網站被禁用 JavaScript 的表現分成了五個 tier:

  1. 一片空白或者就一直加載,沒有任何提示
  2. 無法閱讀,但會檢測沒有開啟 JavaScript (一般會用 <noscript>),並給出相關提示
  3. 可以閱讀,但因為禁用 JavaScript 導致樣式有問題,部分功能受限 (例如切換明暗主題)
  4. 可以閱讀,樣式正常,部分功能受限
  5. 可以閱讀,樣式正常,部分功能受限,合理地處理了需要 JavaScript 的功能 (可能隱藏、可能給出提示、或者用 CSS 禁用)

我得為 JavaScript 辯護一下:

  • 上述的一個 tier,其實有可能是客戶端防自動程式指紋測試,也就是反爬蟲程式。雖然說不少部落格作者不太介意自己的網站被 AI 爬蟲爬,只是現今的爬蟲與以前比起來不太講武德,對網站伺服器構成了巨大的負擔,於是要不要啟用反爬蟲功能其實是一個兩難問題。
  • 第二個 tier 有可能是用以減輕網路頻寬負荷的延遲載入(lazy loading)手段。合適的延遲載入或者客戶端網頁生成可以(在犧牲一點點客戶端性能的前提下)在加快 FCP 的同時降低客戶端帶寬要求。
  • 有些網站有非服務端多語言支援,這個時候你禁用 JavaScript 的話就有可能變成上述的第三個 tier。本站目前語言的切換是全手動的,不會遇到上述問題,但明暗主題切換需要用到 JavaScript。
  • JavaScript 也有寫得好與不好之分。
  • 你現在看到的這個部落格,目前需要依賴 JavaScript 的功能應該只有文章搜尋和隨機文章,禁用 JavaScript 對閱讀體驗的影響應該不是很大。以後可能會加入的依賴 JavaScript 的功能有:內嵌外部影片播放器、留言版、自製互動工具。不過我的 GitHub Pages 除了文檔之外,其他內容基本上都是 JavaScript 程序。

網站搬家?

最近留意到 It’s小白某天決定把整個網站從 GitHub Pages 搬到 Codeberg 上,同時把舊網域直接下架了,結果他還得親自給引用過舊域名的每一個網站寫信改連結,然後他的郵箱就被當成 spam account 了。如果他允許自己使用 JavaScript 的話,他其實只要在舊有的 GitHub repo 塞個 404.html 透過 JavaScript 自動跳轉到新的網站就好,那就不用這麼麻煩。

<!DOCTYPE html><head><title>Redirecting...</title><script>this.location.href=this.location.href.replace("https://old.example.com/blog/","https://new.domain.net/blog/");</script></head><body><p>Redirecting to the new website...</p><noscript><p style="color: #f00">Static hosting requires JavaScript for redirection. Enable JavaScript in your browser first.</p></noscript></body>
💡 Tip

讀者對於以上的論述有什麼想法?歡迎來信 angeci (at) ltgc.cc 與我討論(或者本站出現留言版的時候留個言)!

FFmpeg Command Notes

Last updated on Sunday, August 16, 2026
  • -vn: Remove video
  • -an: Remove audio
  • -c copy: Copy the original codec
  • -c:v: Video codec, such as libx264, libx265, libvpx
  • -c:a: Audio codec, such as aac, libopus, libmp3lame
  • -b:v: Video bitrate
  • -b:a: Audio bitrate

Re-encode

ffmpeg -i input.mp4 -c:v libvpx-vp9 -c:a libopus -b:a 6k output.webm

Changing resolution

Compress the video resolution to 144p:

ffmpeg -i input.mp4 -vf "scale=-1:144" -c:a copy -b:a 16k output.mp4

Crop the video

ffmpeg -i input.mp4 -vf "crop=w:h:x:y" output.mp4

Cut the video

ffmpeg -ss 00:00:00.00 -i input.mp4 -t 00:00:00.00 -c copy output.mp4
  • -ss: Starting point
  • -to: Ending point
  • -t: Duration

Concatenating videos

ffmpeg -f concat -safe 0 -i input1.mp4 -i input2.mp4 -c copy output.mp4

Adding thumbnails

ffmpeg -loop 1 -i cover.jpg -i input.mp4 -c:v libx264 -c:a copy output.mp4

Rotating the video

ffmpeg -i input.mp4 -vf "transpose=2" output.mp4
  • 1 = 90 degrees clockwise
  • 2 = 90 degrees counter-clockwise

Speeding the video

# 2× speed:
ffmpeg -i input.mp4 -filter_complex "[0:v]setpts=0.5*PTS;[0:a]atempo=2.0[a]" -map "[v]" -map "[a]" output.mp4

# 8× speed:
ffmpeg -i input.mp4 -filter_complex "[0:v]setpts=0.125*PTS[v];[0:a]atempo=8.0[a]" -map "[v]" -map "[a]" output.mp4

# Speeding and scaling at the same time:
ffmpeg -i input.mp4 -filter_complex "[0:v]setpts=0.125*PTS[v],scale=-1:144;[0:a]atempo=8.0[a]" -map "[v]" -map "[a]" output.mp4

Convert to an animated image

Convert to animated WebP image:

ffmpeg -i input.mp4 -vf "scale=360:-1,fps=12" -c:v libwebp_anim -loop 0 -compression_level 6 -quality 70 -an output.webp

Adding watermarks

ffmpeg -i input.mp4 -i watermark.png -filter_complex "[0:v][1:v]overlay=10:10:enable='between(t,1,2)'[outv]" -map "[outv]" output.mp4

Silent audio track

ffmpeg -f lavfi -i anullsrc=r=44100:cl=stereo -t 10 output.mp4

One-colour video

ffmpeg -f lavfi -i color-c-black:s=1920x1080:r=1 -t 10 output.mp4

Jet Lag

Am I the only one like this?

Last updated on Sunday, August 16, 2026
⚠️ Notice

This post is a draft translation from the Chinese version which have not yet been thoroughly proofread.

💡 BlogBlog Club!

This is my submission article for “BlogBlog Club Party - September 2026”. This month’s topic is “Staying Up”, hosted by Jason Lai. If you have your own blog, feel free to join us together!

Despite never having travelled to very far places1, and rarely eat during early morning time, my biological clock inexplicably suffers from severe jet lag. This problem seems to be innate; when I’m not in school or working, my mind stays awake until 2 or 3 am before I start feeling sleepy, then I fall into a deep sleep and don’t wake up naturally until the afternoon of the next day2. In recent years, this has been trending later and later. If I try to force myself to go to bed early, I end up with insomnia, lying in bed for hours without being able to fall asleep. However, I personally feel that as long as I’m allowed to go to bed late and wake up late, my sleep is generally sufficient. I only feel sleep-deprived when I force myself to wake up early, as if my biological clock has drifted to another time zone, creating a time difference with the surrounding society. Over time, my lifestyle has become completely reversed, making it impossible for me to adapt to any social demands.

Hypothetical solutions

I’ve been wondering if it’s possible that if I were sent abroad and then sent back, my biological clock might actually be restored. Let’s do the math:

  • Flying westward: Suppose I’m flying from Hong Kong to London. Let’s say I take off at 12 midnight Hong Kong time and arrive in London at 7 am (in summer), which is about 14 hours physically. Of those 14 hours on the plane, the latter 7 hours are roughly my current sleep time, and my biological clock immediately returns to normal upon landing. However, this only considers the outbound journey. It’s said that this approach virtually compresses the day on the return trip, essentially forcing myself to go to sleep earlier again, making the symptoms of a disrupted biological clock more likely to recur.
  • Flying eastward: Suppose I’m flying from Hong Kong to Vancouver. Let’s say I take off at 12 noon Hong Kong time and arrive in Vancouver at 9 am (in summer), which is about 12 hours physically. I’ll arrive in what would be afternoon on my biological clock, and then I’ll start staying up late to fall asleep in what feels like the early morning (late night on the West Coast of North America). However, to correct my biological clock this way, I would probably have to stay in North America for at least a week, which would essentially shift my biological clock phase backward until the time difference exceeds 24 hours. Doesn’t that seem to put a greater strain on my body?

Poor light exposure

Scientific research suggests that if you simply want to adjust your biological clock, light exposure may be more effective than a long-distance travel. In fact, my light exposure habits in Hong Kong are already quite poor, I’m constantly exposed to indoor environments filled with white and blue light, even late at night. Perhaps I should install a warm light in the room where my brain is working at its peak late at night.

Light mode and dark mode

This site currently offers both light and dark themes, with automatic detection by default, but users can also switch between both themes by clicking a button on the menu.

But what if you’re forced to choose one? CCP Propaganda Alex Hsu mentioned in “The omakase blog: building an opinionated personal site” that he removed the light mode entirely, which I think is fine. Conversely, since I’m the kind of person who likes to hide in a dark room late at night to look at my phone, I don’t really like the constanly blindingly bright mode of 廢文小天地 and Wen (that kind of blindingly bright mode is more suitable for e-ink screens or paper reading, maybe I should invest in an e-reader?). In the ancient days before CSS, the default layout was always in light mode, which is why browsers now default to light mode unless colours are specified using CSS.


  1. Don’t blame me for being from a poor family and struggling financially. ↩︎

  2. As we all know, sunrise is the start of a day. ↩︎

Ichigo Ichie

⚠️ Notice

This post is a draft translation from the Chinese version which have not yet been thoroughly proofread.

💡 BlogBlog Club!

This is my submission article for “BlogBlog Club Party - August 2026”. This month’s topic is “Ichigo Ichie”, hosted by ikuka. If you have your own blog, feel free to join us together!

不是很知道該寫點什麼上去,來寫點哲♂️學隨筆好了。

確定性與石沉大海的哲學

我不知道我這樣說會不會被 Wiwi 部落格宇宙視為「異端」。有些人喜歡隨機、喜歡不確定性、喜歡選擇性無視外界的資訊。而我呢就恰恰相反,比較喜歡確定性、比較喜歡可以掌控一切的感覺,而不太喜歡無了期等待的不確定性,但不代表我不喜歡新鮮感。這種性格倒是讓我不致於沉迷那些具有較多隨機性的主流手遊。

但與人交際時就比較容易出問題了。我有過一些與BlogBlog 同樂會中的中共黨員交涉的經驗,寄出去的郵件全部石沉大海。這溝通方式跟中共別無二致,中共黨員實錘了,我再也不會主動讀牠們的網站了。這也算是我和這些匪諜之間的一期一會吧。

有些事情錯過了就是錯過了,你也別想挽回了。


不過與此同時,哪怕是我這種比較偏好確定性的人,生活當中很多時候也不得不接受許多的「一期一會」。

  • 以前工作的場所,有時候能碰見一些能吸引我注意力的人,但是我當時的工作上沒有接觸人的義務,我沒有機會和他們作進一步接觸,以後也就沒有機會再相見。(不過我本來就不適合接觸陌生人。)
  • 在找到幾家順路、合我口味、CP 值又高的餐廳,吃過幾次之後,就不見了。(被消失?)

回不去了 😢

我以前常常憧憬着能夠和其他人一樣,能夠找到適合的知己、過上充實的大學生活,但由於偏科的緣故沒能考上正經的大學,只能跟無數英語被當的人一起修讀英語進修課程(明明我成績的缺口在中文啊?)。不過就算我當時真的考上了也沒用,疫情跟香港社會形勢的變化(你懂的)也不會讓我過上我所憧憬的大學生活。

我一直很渴望有一天,能夠找到適合的知己、補上我成長記憶當中缺失的部份。不過現在來看似乎已經不太可能了。現在我還得擔心,萬一某天三戰全面爆發,我能不能找到一個好的依靠?能不能照顧好自己?

回不去了,也許這就是真正的一期一會?

看來我知道得太多了,心很累。

你不是懶,而是看清了這代人的結局。